@@ -54,15 +54,15 @@ do_request <- function(x, ...) {
 #'   content, one component per page.
 #' @examples
 #' \dontrun{
-#' ## build a request for an endpoint that is:
-#' ##   * paginated
-#' ##   * NOT privileged in googledrive, i.e. not covered by request_generate()
-#' ## "comments" are a great example
-#' ## https://developers.google.com/drive/v3/reference/comments
-#' ##
-#' ## Practice with a target file with > 2 comments
-#' ## Note that we request 2 items (comments) per page
-#' req <- build_request(
+#' # build a request for an endpoint that is:
+#' #   * paginated
+#' #   * NOT privileged in googledrive, i.e. not covered by request_generate()
+#' # "comments" are a great example
+#' # https://developers.google.com/drive/v3/reference/comments
+#' #
+#' # Practice with a target file with > 2 comments
+#' # Note that we request 2 items (comments) per page
+#' req <- gargle::request_build(
 #'   path = "drive/v3/files/{fileId}/comments",
 #'   method = "GET",
 #'   params = list(
@@ -72,15 +72,17 @@ do_request <- function(x, ...) {
 #'   ),
 #'   token = googledrive::drive_token()
 #' )
-#' ## make the paginated request, but cap it at 1 page
-#' ## should get back exactly two comments
+#' # make the paginated request, but cap it at 1 page
+#' # should get back exactly two comments
 #' do_paginated_request(req, n_max = 1)
 #' }
 do_paginated_request <- function(x,
                                  ...,
                                  n_max = Inf,
                                  n = function(res) 1,
-                                 verbose = TRUE) {
+                                 verbose = deprecated()) {
+  warn_for_verbose(verbose)
+
   ## when traversing pages, you can't cleanly separate the task into
   ## request_make() and gargle::response_process(), because you need to process
   ## response / page i to get the pageToken for request / page i + 1
@@ -97,24 +99,40 @@ do_paginated_request <- function(x,
   responses <- list()
   i <- 1
   total <- 0
+  # TODO: do I have anything to say here at the beginning?
+  # what's a non-jargon-y and general way to say:
+  # "we're hitting a paginated endpoint and we're working with pageSize n"
+  st <- show_status()
+  if (st) sb <- cli::cli_status(msg = character())
   repeat {
     page <- request_make(x, ...)
     responses[[i]] <- gargle::response_process(page)
     x$query$pageToken <- responses[[i]]$nextPageToken
     x$url <- httr::modify_url(x$url, query = x$query)
+    # TODO: presumably this might need some generalization when this moves
+    # to gargle (how we determine how much 'stuff' we've seen and how we
+    # talk about it in the status bar)
+    # TODO: need to do something re: non-interactive work, e.g. Rmd
     total <- total + n(responses[[i]])
-    if (verbose && i == 2) message_glue("Items so far: ")
-    if (verbose && i > 1) message_glue("{total} ", .appendLF = FALSE)
     if (is.null(x$query$pageToken) || total >= n_max) {
-      if (verbose && i > 1) message("")
       break
     }
+    if (st) {
+      cli::cli_status_update(
+        id = sb,
+        "{cli::symbol$arrow_right} Files retrieved so far: {total}"
+      )
+    }
     i <- i + 1
   }
 
   responses
 }
 
+show_status <- function() {
+  is_interactive() && is_false(getOption("googledrive_quiet", FALSE))
+}
+
 drive_ua <- function() {
   httr::user_agent(paste0(
     "googledrive/", utils::packageVersion("googledrive"), " ",
